@@ -24,9 +24,12 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_SENDRESPONSE
 );
 
-our $VERSION = '2.0.3';
+our $VERSION = '2.0.9';
 
-extends 'Lemonldap::NG::Portal::Main::Auth', 'Lemonldap::NG::Portal::Lib::SAML';
+extends qw(
+  Lemonldap::NG::Portal::Main::Auth
+  Lemonldap::NG::Portal::Lib::SAML
+);
 
 # INTERFACE
 
@@ -294,9 +297,13 @@ sub extractFormInfo {
             }
 
             # Get NameID
-            my $nameid         = $login->nameIdentifier;
-            my $nameid_content = $nameid->content;
+            my $nameid = $login->nameIdentifier;
+            unless ($nameid) {
+                $self->userLogger->error("No NameID element found");
+                return PE_SAML_SSO_ERROR;
+            }
 
+            my $nameid_content = $nameid->content;
             unless ($nameid_content) {
                 $self->userLogger->error("No NameID value found");
                 return PE_SAML_SSO_ERROR;
@@ -778,7 +785,7 @@ sub extractFormInfo {
                 $req->response( [
                         200,
                         [
-                            'Content-Type'   => 'application/xml',
+                            'Content-Type'   => 'text/xml',
                             'Content-Length' => length($slo_body)
                         ],
                         [$slo_body]
@@ -846,7 +853,7 @@ sub extractFormInfo {
         $req->response( [
                 200,
                 [
-                    'Content-Type'   => 'application/xml',
+                    'Content-Type'   => 'text/xml',
                     'Content-Length' => length($art_response)
                 ],
                 [$art_response]
@@ -859,7 +866,7 @@ sub extractFormInfo {
     # 2. IDP resolution
 
     # Search a selected IdP
-    my ( $idp, $idp_cookie ) = $self->getIDP($req);
+    my $idp = $self->getIDP($req);
 
     # Use Common Domain Cookie
     if (   !$idp
@@ -972,48 +979,13 @@ sub extractFormInfo {
               or $a->{name} cmp $b->{name}
               or $a->{val} cmp $b->{val}
           } @list;
-        $req->data->{list}            = \@list;
-        $req->data->{confirmRemember} = 1;
-
-        # Delete existing IDP resolution cookie
-        $req->addCookie(
-            $self->p->cookie(
-                name    => $self->conf->{samlIdPResolveCookie},
-                value   => 0,
-                domain  => $self->conf->{domain},
-                secure  => 0,
-                expires => 'Wed, 21 Oct 2015 00:00:00 GMT',
-            )
-        );
+        $req->data->{list} = \@list;
 
         #TODO: check this
         $req->data->{login} = 1;
         return PE_IDPCHOICE;
     }
 
-    # Store choosen IDP in cookie
-    unless ( $idp_cookie and $idp eq $idp_cookie ) {
-        $self->logger->debug("Build cookie to remember $idp as IDP choice");
-
-        # Control url parameter
-        my $urlcheck = $self->p->controlUrl($req);
-        return $urlcheck unless ( $urlcheck == PE_OK );
-
-        # User can choose temporary (0) or persistent cookie (1)
-        my $cookie_type = $req->param("cookie_type") || "0";
-
-        # Cookie available 1 year
-        $req->addCookie(
-            $self->p->cookie(
-                name   => $self->conf->{samlIdPResolveCookie},
-                value  => $idp,
-                domain => $self->conf->{domain},
-                secure => $self->conf->{securedCookie},
-                ( $cookie_type ? ( max_age => 31557600 ) : () ),
-            )
-        );
-    }
-
     # 3. Build authentication request
 
     # IDP conf key
@@ -1302,7 +1274,8 @@ sub authFinish {
 
     $self->logger->debug( "Store NameID "
           . $nameid->dump
-          . " and SessionIndex $session_index for session $id" );
+          . ( $session_index ? " and SessionIndex $session_index" : "" )
+          . " for session $id" );
 
     my $infos;
     $infos->{type}          = 'saml';            # Session type
@@ -1398,7 +1371,7 @@ sub authLogout {
 
         $req->urldc($slo_url);
 
-        # Redirect done in Portal/Simple.pm
+        # Redirect done in Portal
         return PE_OK;
     }
 
@@ -1416,10 +1389,10 @@ sub authLogout {
         $req->postFields( { 'SAMLRequest' => $slo_body } );
 
         # RelayState
-        $self->postFields->{'RelayState'} = $logout->msg_relayState
+        $req->postFields->{'RelayState'} = $logout->msg_relayState
           if ( $logout->msg_relayState );
 
-        # Post done in Portal/Simple.pm
+        # Post done in Portal
         $req->steps( [ 'deleteSession', 'autoPost' ] );
         return PE_OK;
     }
@@ -1441,6 +1414,15 @@ sub authLogout {
         # Create Logout object
         $logout = $self->createLogout( $self->lassoServer );
 
+        # Do we check signature?
+        my $checkSLOMessageSignature =
+          $self->conf->{samlIDPMetaDataOptions}->{$idpConfKey}
+          ->{samlIDPMetaDataOptionsCheckSLOMessageSignature};
+
+        unless ($checkSLOMessageSignature) {
+            $self->disableSignatureVerification($logout);
+        }
+
         # Process logout response
         my $result = $self->processLogoutResponseMsg( $logout, $response );
 
@@ -1487,7 +1469,6 @@ sub getDisplayType {
 
 # Try to find an IdP using :
 # * HTTP parameter
-# * "samlIdPResolveCookie" cookie
 # * Rules
 #
 # @return Array containing :
@@ -1498,8 +1479,6 @@ sub getIDP {
     my $idp;
     my $idpName;
 
-    my $idp_cookie = $req->cookies->{ $self->{conf}->{samlIdPResolveCookie} };
-
     # Case 1: Recover IDP from idp URL Parameter
     unless ( $idp = $req->param("idp") ) {
 
@@ -1510,35 +1489,31 @@ sub getIDP {
                 if ( $idpName eq $idpConfKey ) {
                     $idp = $_;
                     $self->logger->debug(
-                        "IDP $idp found from idpName URL Parameter ($idpName)");
+"IDP $idp selected from idpName URL Parameter ($idpName)"
+                    );
                     last;
                 }
             }
         }
 
-        # Case 3: Recover IDP from cookie
-        if ( !$idp and $idp = $idp_cookie ) {
-            $self->logger->debug("IDP $idp found in IDP resolution cookie");
-        }
-
-        # Case 4: check all IDP resolution rules
+        # Case 3: check all IDP resolution rules
         # The first match win
         else {
             foreach ( keys %{ $self->idpList } ) {
                 my $idpConfKey = $self->idpList->{$_}->{confKey};
-                my $cond = $self->idpRules->{$idpConfKey} or next;
+                my $cond       = $self->idpRules->{$_} or next;
                 if ( $cond->( $req, $req->sessionInfo ) ) {
                     $self->logger->debug(
-                        "IDP $idpConfKey resolution rule match");
+                        "IDP $idpConfKey selected from resolution rule");
                     $idp = $_;
                     last;
                 }
             }
         }
-        $self->logger->debug('No IDP found') unless ($idp);
+        $self->logger->debug('No IDP selected') unless ($idp);
     }
     else {
-        $self->logger->debug("IDP $idp found from idp URL Parameter");
+        $self->logger->debug("IDP $idp selected from idp URL Parameter");
     }
 
     # Case 6: auto select IDP if only one IDP defined
@@ -1553,7 +1528,7 @@ sub getIDP {
         $idp = undef;
     }
 
-    return ( $idp, $idp_cookie );
+    return $idp;
 }
 
 1;
