@@ -7,11 +7,11 @@ package Lemonldap::NG::Portal::UserDB::Demo;
 
 use strict;
 use Mouse;
-use Lemonldap::NG::Portal::Main::Constants qw(PE_OK PE_USERNOTFOUND);
+use Lemonldap::NG::Portal::Main::Constants qw(PE_OK PE_BADCREDENTIALS);
 
 extends 'Lemonldap::NG::Common::Module';
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.9';
 
 # Sample accounts from Doctor Who characters
 our %demoAccounts = (
@@ -32,6 +32,12 @@ our %demoAccounts = (
     },
 );
 
+our %demoGroups = (
+    'timelords'  => [qw(dwho)],
+    'earthlings' => [qw(msmith rtyler)],
+    'users'      => [qw(dwho msmith rtyler)],
+);
+
 # INITIALIZATION
 
 sub init {
@@ -44,26 +50,23 @@ sub init {
 # Check known accounts
 # @return Lemonldap::NG::Portal constant
 sub getUser {
-    my ( $self, $req ) = @_;
+    my ( $self, $req, %args ) = @_;
 
-    # Search by login
-    if ( $req->user ) {
+    if ( $args{useMail} ) {
+        my ($user) = grep { $demoAccounts{$_}->{mail} eq $req->{user} }
+          keys %demoAccounts;
+        if ($user) {
+            $req->{user} = $user;
+            return PE_OK;
+        }
+    }
+    else {
         return PE_OK
           if ( defined $demoAccounts{ $req->user } );
     }
 
-    # Search by mail
-    if ( $req->{mail} ) {
-        return PE_OK
-          if (
-            ( $req->{user} ) =
-            grep { $demoAccounts{$_}->{mail} eq $req->{mail} }
-            keys %demoAccounts
-          );
-    }
-
     eval { $self->p->_authentication->setSecurity($req) };
-    PE_USERNOTFOUND;
+    PE_BADCREDENTIALS;
 }
 
 ## @apmethod int setSessionInfo()
@@ -75,8 +78,7 @@ sub setSessionInfo {
     my %vars = ( %{ $self->conf->{exportedVars} },
         %{ $self->conf->{demoExportedVars} } );
     while ( my ( $k, $v ) = each %vars ) {
-        $req->{sessionInfo}->{$k} = $demoAccounts{ $req->{user} }->{$v}
-          || "";
+        $req->{sessionInfo}->{$k} = $demoAccounts{ $req->{user} }->{$v};
     }
 
     PE_OK;
@@ -86,6 +88,21 @@ sub setSessionInfo {
 # Do nothing
 # @return Lemonldap::NG::Portal constant
 sub setGroups {
+    my ( $self, $req ) = @_;
+    my $user    = $req->user;
+    my $groups  = $req->sessionInfo->{groups} || '';
+    my $hGroups = $req->sessionInfo->{hGroups} || {};
+    for my $grp ( keys %demoGroups ) {
+        if ( grep { $_ eq $user } @{ $demoGroups{$grp} } ) {
+            $hGroups->{$grp} = { 'name' => $grp };
+            $groups =
+              ($groups)
+              ? $groups . $self->conf->{multiValuesSeparator} . $grp
+              : $grp;
+        }
+    }
+    $req->sessionInfo->{groups}  = $groups;
+    $req->sessionInfo->{hGroups} = $hGroups;
     PE_OK;
 }
 
