@@ -6,10 +6,11 @@ use Lemonldap::NG::Portal::Main::Constants qw(PE_OK PE_MISSINGREQATTR);
 
 extends 'Lemonldap::NG::Common::Module';
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
 has vars => (
     is      => 'rw',
+    lazy    => 1,
     builder => sub {
         return {
             %{ $_[0]->conf->{exportedVars} },
@@ -39,7 +40,7 @@ sub setSessionInfo {
         my $v        = $self->{vars}->{$k};
         my $attr     = $k;
         my $required = ( $attr =~ s/^!// ) ? 1 : 0;
-        $req->{sessionInfo}->{$attr} = $req->datas->{_facebookDatas}->{$v};
+        $req->{sessionInfo}->{$attr} = $req->data->{_facebookData}->{$v};
         if ( $required and not( defined $req->{sessionInfo}->{$attr} ) ) {
             $self->logger->warn(
 "Required parameter $v is not provided by Facebook server, aborted"
