@@ -2,15 +2,16 @@ package Lemonldap::NG::Portal::UserDB::REST;
 
 use strict;
 use Mouse;
+use JSON;
 use Lemonldap::NG::Portal::Main::Constants qw(
   PE_ERROR
   PE_OK
-  PE_USERNOTFOUND
+  PE_BADCREDENTIALS
 );
 
 extends 'Lemonldap::NG::Common::Module', 'Lemonldap::NG::Portal::Lib::REST';
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.9';
 
 # INITIALIZATION
 
@@ -28,26 +29,36 @@ sub init {
 # RUNNING METHODS
 
 sub getUser {
-    my ( $self, $req ) = @_;
-    my $res = eval {
-        $self->restCall( $self->conf->{restUserDBUrl}, { user => $req->user } );
+    my ( $self, $req, %args ) = @_;
+    my $res;
+    $res = eval {
+        $self->restCall(
+            $self->conf->{restUserDBUrl},
+            {
+                ( $args{useMail} ? 'mail' : 'user' ) => $req->user,
+                'useMail' => ( $args{useMail} ? JSON::true : JSON::false ),
+
+            }
+        );
     };
     if ($@) {
         $self->logger->error("UserDB REST error: $@");
+        eval { $self->p->_authentication->setSecurity($req) };
         return PE_ERROR;
     }
     unless ( $res->{result} ) {
         $self->userLogger->warn( 'User ' . $req->user . ' not found' );
-        return PE_USERNOTFOUND;
+        eval { $self->p->_authentication->setSecurity($req) };
+        return PE_BADCREDENTIALS;
     }
-    $req->datas->{restUserDBInfo} = $res->{info} || {};
+    $req->data->{restUserDBInfo} = $res->{info} || {};
     return PE_OK;
 }
 
 sub setSessionInfo {
     my ( $self, $req ) = @_;
-    $req->sessionInfo->{$_} = $req->datas->{restUserDBInfo}->{$_}
-      foreach ( keys %{ $req->datas->{restUserDBInfo} } );
+    $req->sessionInfo->{$_} = $req->data->{restUserDBInfo}->{$_}
+      foreach ( keys %{ $req->data->{restUserDBInfo} } );
     PE_OK;
 }
 
