@@ -7,12 +7,18 @@ package Lemonldap::NG::Portal::UserDB::Slave;
 
 use strict;
 use Mouse;
-use Lemonldap::NG::Portal::Lib::Slave;
-use Lemonldap::NG::Portal::Main::Constants qw(PE_FORBIDDENIP PE_OK);
 
-our $VERSION = '1.9.991_01';
+use Lemonldap::NG::Portal::Main::Constants qw(
+  PE_OK
+  PE_FORBIDDENIP
+);
 
-extends 'Lemonldap::NG::Common::Module';
+our $VERSION = '2.0.10';
+
+extends qw(
+  Lemonldap::NG::Common::Module
+  Lemonldap::NG::Portal::Lib::Slave
+);
 
 # INITIALIZATION
 
